pub struct ZenConsoleInput;Expand description
The main struct for ZenConsoleInput.
Use this struct to create new input, password, or selection prompts.
Implementations
Sourceimpl ZenConsoleInput
impl ZenConsoleInput
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ZenConsoleInput instance.
Examples found in repository?
examples/demo.rs (line 4)
3fn main() {
4 let zci = ZenConsoleInput::new();
5
6 // Simple input
7 let name = zci.input().message("Enter your name: ").get_input();
8 println!("Hello, {}!", name);
9
10 // Input with default value
11 let age: u32 = zci
12 .input()
13 .message("Enter your age [19]: ")
14 .default("19")
15 .get_parsed_input();
16 println!("You are {} years old.", age);
17
18 // Multiline input (with optional editor support)
19 let bio = zci
20 .input()
21 .message("Enter your bio")
22 .multiline()
23 .get_input();
24 println!("Your bio:\n{}", bio);
25
26 // Selection
27 let favorite_color = zci
28 .selection()
29 .message("Choose your favorite color")
30 .options(vec![
31 "Red".to_string(),
32 "Green".to_string(),
33 "Blue".to_string(),
34 ])
35 .get_selection();
36 println!("Your favorite color is {}", favorite_color);
37
38 // Password
39 let password = zci
40 .password()
41 .message("Enter your password: ")
42 .get_password();
43 println!("Your password is {} characters long", password.len());
44}Sourcepub fn input(&self) -> Input
pub fn input(&self) -> Input
Creates a new Input instance for text input.
Examples found in repository?
examples/demo.rs (line 7)
3fn main() {
4 let zci = ZenConsoleInput::new();
5
6 // Simple input
7 let name = zci.input().message("Enter your name: ").get_input();
8 println!("Hello, {}!", name);
9
10 // Input with default value
11 let age: u32 = zci
12 .input()
13 .message("Enter your age [19]: ")
14 .default("19")
15 .get_parsed_input();
16 println!("You are {} years old.", age);
17
18 // Multiline input (with optional editor support)
19 let bio = zci
20 .input()
21 .message("Enter your bio")
22 .multiline()
23 .get_input();
24 println!("Your bio:\n{}", bio);
25
26 // Selection
27 let favorite_color = zci
28 .selection()
29 .message("Choose your favorite color")
30 .options(vec![
31 "Red".to_string(),
32 "Green".to_string(),
33 "Blue".to_string(),
34 ])
35 .get_selection();
36 println!("Your favorite color is {}", favorite_color);
37
38 // Password
39 let password = zci
40 .password()
41 .message("Enter your password: ")
42 .get_password();
43 println!("Your password is {} characters long", password.len());
44}Sourcepub fn selection(&self) -> Selection
pub fn selection(&self) -> Selection
Creates a new Selection instance for choosing from a list of options.
Examples found in repository?
examples/demo.rs (line 28)
3fn main() {
4 let zci = ZenConsoleInput::new();
5
6 // Simple input
7 let name = zci.input().message("Enter your name: ").get_input();
8 println!("Hello, {}!", name);
9
10 // Input with default value
11 let age: u32 = zci
12 .input()
13 .message("Enter your age [19]: ")
14 .default("19")
15 .get_parsed_input();
16 println!("You are {} years old.", age);
17
18 // Multiline input (with optional editor support)
19 let bio = zci
20 .input()
21 .message("Enter your bio")
22 .multiline()
23 .get_input();
24 println!("Your bio:\n{}", bio);
25
26 // Selection
27 let favorite_color = zci
28 .selection()
29 .message("Choose your favorite color")
30 .options(vec![
31 "Red".to_string(),
32 "Green".to_string(),
33 "Blue".to_string(),
34 ])
35 .get_selection();
36 println!("Your favorite color is {}", favorite_color);
37
38 // Password
39 let password = zci
40 .password()
41 .message("Enter your password: ")
42 .get_password();
43 println!("Your password is {} characters long", password.len());
44}Sourcepub fn password(&self) -> Password
pub fn password(&self) -> Password
Creates a new Password instance for password input.
Examples found in repository?
examples/demo.rs (line 40)
3fn main() {
4 let zci = ZenConsoleInput::new();
5
6 // Simple input
7 let name = zci.input().message("Enter your name: ").get_input();
8 println!("Hello, {}!", name);
9
10 // Input with default value
11 let age: u32 = zci
12 .input()
13 .message("Enter your age [19]: ")
14 .default("19")
15 .get_parsed_input();
16 println!("You are {} years old.", age);
17
18 // Multiline input (with optional editor support)
19 let bio = zci
20 .input()
21 .message("Enter your bio")
22 .multiline()
23 .get_input();
24 println!("Your bio:\n{}", bio);
25
26 // Selection
27 let favorite_color = zci
28 .selection()
29 .message("Choose your favorite color")
30 .options(vec![
31 "Red".to_string(),
32 "Green".to_string(),
33 "Blue".to_string(),
34 ])
35 .get_selection();
36 println!("Your favorite color is {}", favorite_color);
37
38 // Password
39 let password = zci
40 .password()
41 .message("Enter your password: ")
42 .get_password();
43 println!("Your password is {} characters long", password.len());
44}Auto Trait Implementations
impl Freeze for ZenConsoleInput
impl RefUnwindSafe for ZenConsoleInput
impl Send for ZenConsoleInput
impl Sync for ZenConsoleInput
impl Unpin for ZenConsoleInput
impl UnsafeUnpin for ZenConsoleInput
impl UnwindSafe for ZenConsoleInput